/* USER CODE BEGIN Header */
/**
  ******************************************************************************
  * @file           : main.h
  * @brief          : Header for main.c file.
  *                   This file contains the common defines of the application.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; Copyright (c) 2020 STMicroelectronics.
  * All rights reserved.</center></h2>
  *
  * This software component is licensed by ST under BSD 3-Clause license,
  * the "License"; You may not use this file except in compliance with the
  * License. You may obtain a copy of the License at:
  *                        opensource.org/licenses/BSD-3-Clause
  *
  ******************************************************************************
  */
/* USER CODE END Header */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __MAIN_H
#define __MAIN_H

#ifdef __cplusplus
extern "C" {
#endif



/* Includes ------------------------------------------------------------------*/
#include "stm32g0xx_hal.h"
#include "stm32g0xx_ll_system.h"

/* Private includes ----------------------------------------------------------*/
/* USER CODE BEGIN Includes */

#define MAX_STR_LENTH		64
#define MAX_LCD_LENTH		64
#define SWITCH_INPUT_CHECK_TIME	40
#define INPUT_CHECK_TIME	20

/* USER CODE END Includes */

/* Exported types ------------------------------------------------------------*/
/* USER CODE BEGIN ET */

// LCD command
#define CHAR_LCD_RESET				0xCA
#define CHAR_LCD_LINE				0xCB
#define CHAR_LCD_SHOW				0xCC
#define CHAR_LCD_INSTRUCTION		0xCD
#define CHAR_LCD_CGRAM				0xCE

// general command
#define CHAR_CR						0x0D
#define CHAR_LF						0x0A
#define CHAR_0xff					0xff
/*
#define COLOUR_VALUE_GREEN			2016
#define COLOUR_VALUE_RED			63488
#define COLOUR_VALUE_ORANGE			64512
#define COLOUR_VALUE_YELLOW			65504
#define COLOUR_VALUE_BLACK			1
#define COLOUR_VALUE_GRAY			33808
#define COLOUR_VALUE_WHITE			65535

#define ADDR_EEPROM_COUNT			0x0020
#define ADDR_EEPROM_BRIGHT			0x0030
*/

#define STR_UART_FILENAME			"XYB-CONV-210803.ioc\r\n"

#define STR_FILE_L1					"f: XYB-IO24-CONV"
#define STR_FILE_L2					"    V1.0-210803 "


#define BUZZ_ON_VALUE				40
#define BUZZ_OFF_VALUE				30
#define BUZZ_EMG_ON_VALUE			600

#define LAMP_SLOW_ON_VALUE			400
#define LAMP_SLOW_OFF_VALUE			400

#define LAMP_FAST_ON_VALUE			150
#define LAMP_FAST_OFF_VALUE			150

/* USER CODE END ET */

/* Exported constants --------------------------------------------------------*/
/* USER CODE BEGIN EC */

typedef struct
{
	uint16_t tmrs;
	uint16_t vlue;
	uint8_t tov		:1;
	uint8_t togg	:1;

}delaytable;
delaytable T_DELAY;
delaytable T_LCD;
delaytable T_MANU;
delaytable U1G;
delaytable U2G;
delaytable U3G;

typedef struct
{

	uint16_t strnum;
	char RxString[MAX_STR_LENTH];
	char TxString[MAX_STR_LENTH];
	char RxQueue[MAX_STR_LENTH];
	uint8_t RcvTemp[2];
	uint8_t RxData;
	uint8_t RxHead;
	uint8_t RxTail;

	uint8_t RcvTimeVal;
	uint8_t RcvTimer;

	uint8_t Rcv_Data;
	uint8_t Ridx;
	uint8_t rcv_cnt;
	uint8_t Mode;

	uint8_t Rcv_OverTmr				:1;
	uint8_t Rcv_Flag				:1;
	uint8_t Trmt_Flag				:1;
	uint8_t Xycv_Rcv_Flag			:1;

}UartsData;
UartsData U1;
UartsData U2;
UartsData U3;

typedef struct
{

	uint16_t strnum;
	uint16_t add;
	char RxString[8];
	char TxString[8];
	char RxQueue[8];

	uint8_t RcvTemp[2];

	uint8_t RxData;
	uint8_t RxHead;

	uint8_t RcvTimeVal;
	uint8_t RcvTimer;

	uint8_t Mode;
	uint8_t Rcv_OverTmr				:1;
	uint8_t Rcv_Flag				:1;
	uint8_t Trmt_Flag				:1;

}CommData;
CommData I2C_1;
CommData SPI_1;


typedef struct
{
	uint8_t Tmr;
	uint8_t	Stat;
	uint8_t	Togg;

}Button_Data;

Button_Data	btn_SET;
Button_Data	btn_SHIFT;
Button_Data	btn_UP;
Button_Data	btn_DOWN;

Button_Data	btn_LEFT;
Button_Data	btn_RIGHT;
Button_Data	btn_EMG;


typedef struct
{
	uint16_t Tmr;
	uint8_t	Input;
	uint8_t	New_Input			:1;
	uint8_t	Tog_Input			:1;
}Input_Data;

Input_Data SW_01;
Input_Data SW_02;
Input_Data SW_03;
Input_Data SW_04;

Input_Data INP_01;
Input_Data INP_02;
Input_Data INP_03;
Input_Data INP_04;
Input_Data INP_05;
Input_Data INP_06;
Input_Data INP_07;
Input_Data INP_08;



typedef struct
{
	uint16_t Tmr;
	uint8_t	Output;
	uint8_t	New_Output			:1;
	uint8_t	Tog_Output			:1;

}Output_Data;

Output_Data OUT_01;
Output_Data OUT_02;
Output_Data OUT_03;
Output_Data OUT_04;
Output_Data OUT_05;
Output_Data OUT_06;
Output_Data OUT_07;
Output_Data OUT_08;


typedef struct
{
	uint16_t Tmr;
	uint16_t OnValue;
	uint16_t OffValue;
	uint8_t	Output;
	uint8_t	Outidx;
	uint8_t	Stat;
	uint8_t	Idx;

}Lamp_Output_Data;

Lamp_Output_Data LEFT_LAMP;
Lamp_Output_Data RIGHT_LAMP;
Lamp_Output_Data EMG_LAMP;
Lamp_Output_Data BUZZ;


typedef struct
{
	uint8_t	Stat;
	uint8_t	Idx;

}Manual_Data;

Manual_Data MAIN;
Manual_Data MANU;


typedef struct
{
	uint16_t Txlen;
	uint16_t Blktmr;
	uint16_t BlktmrVlu;
	char Txstr[MAX_LCD_LENTH];
	char Line1[MAX_LCD_LENTH];
	char Line2[MAX_LCD_LENTH];
	uint8_t	PointChar;
	uint8_t	Idx;
	uint8_t	Blink_on			:1;
}Lcd_Data;

Lcd_Data LCD;



typedef struct
{
	uint8_t Mode;
	uint8_t Run;
	uint8_t Dir;
	uint16_t Speed;
	uint16_t Torq;
	uint8_t Accel;
	uint8_t Decel;
	uint32_t Zcc;
	char Rxstr[MAX_LCD_LENTH];
	char Valstr[8];

}Xycv_Data;

Xycv_Data XYCV_SET;
Xycv_Data XYCV_RCV;



enum t_index
{

result_false=0,
result_true,

lamp_off=10,
lamp_on,
blink_once,
blink_continue,

button_pressed=20,
button_released,

beep_off=30,
beep_once,
beep_pass,
beep_fail,
beep_emergency,

idx_xycv_run=100,
idx_xycv_stop,
idx_xycv_cw,
idx_xycv_ccw,

idx_SpiMode_Master=230,
idx_SpiMode_Slave,

idx_uart3_baud_115200,
idx_uart3_baud_9600,

idx_none=250

};

uint8_t read_i2c_data;
uint8_t Hmi_BrightValue;

uint16_t prtb_in;
uint16_t prtc_in;
uint16_t prtd_in;




uint8_t CHECK_NUM(uint8_t ch);





/* USER CODE END EC */

/* Exported macro ------------------------------------------------------------*/
/* USER CODE BEGIN EM */

/* USER CODE END EM */

/* Exported functions prototypes ---------------------------------------------*/
void Error_Handler(void);

/* USER CODE BEGIN EFP */



/* USER CODE END EFP */

/* Private defines -----------------------------------------------------------*/
#define SWITCH_04_Pin GPIO_PIN_11
#define SWITCH_04_GPIO_Port GPIOC
#define SWITCH_03_Pin GPIO_PIN_12
#define SWITCH_03_GPIO_Port GPIOC
#define STATUS_LED_Pin GPIO_PIN_1
#define STATUS_LED_GPIO_Port GPIOC
#define BUZZER_Pin GPIO_PIN_2
#define BUZZER_GPIO_Port GPIOC
#define SPI1_CS_Pin GPIO_PIN_1
#define SPI1_CS_GPIO_Port GPIOB
#define OUTPUT_08_Pin GPIO_PIN_6
#define OUTPUT_08_GPIO_Port GPIOC
#define OUTPUT_07_Pin GPIO_PIN_7
#define OUTPUT_07_GPIO_Port GPIOC
#define OUTPUT_06_Pin GPIO_PIN_8
#define OUTPUT_06_GPIO_Port GPIOD
#define OUTPUT_05_Pin GPIO_PIN_9
#define OUTPUT_05_GPIO_Port GPIOD
#define OUTPUT_04_Pin GPIO_PIN_11
#define OUTPUT_04_GPIO_Port GPIOA
#define OUTPUT_02_Pin GPIO_PIN_15
#define OUTPUT_02_GPIO_Port GPIOA
#define OUTPUT_01_Pin GPIO_PIN_8
#define OUTPUT_01_GPIO_Port GPIOC
#define OUTPUT_03_Pin GPIO_PIN_9
#define OUTPUT_03_GPIO_Port GPIOC
#define EMG_LAMP_Pin GPIO_PIN_0
#define EMG_LAMP_GPIO_Port GPIOD
#define RIGHT_LAMP_Pin GPIO_PIN_1
#define RIGHT_LAMP_GPIO_Port GPIOD
#define LEFT_LAMP_Pin GPIO_PIN_2
#define LEFT_LAMP_GPIO_Port GPIOD
#define INPUT_01_Pin GPIO_PIN_3
#define INPUT_01_GPIO_Port GPIOD
#define INPUT_02_Pin GPIO_PIN_4
#define INPUT_02_GPIO_Port GPIOD
#define INPUT_03_Pin GPIO_PIN_5
#define INPUT_03_GPIO_Port GPIOD
#define INPUT_04_Pin GPIO_PIN_6
#define INPUT_04_GPIO_Port GPIOD
#define INPUT_05_Pin GPIO_PIN_3
#define INPUT_05_GPIO_Port GPIOB
#define INPUT_06_Pin GPIO_PIN_4
#define INPUT_06_GPIO_Port GPIOB
#define INPUT_07_Pin GPIO_PIN_5
#define INPUT_07_GPIO_Port GPIOB
#define INPUT_08_Pin GPIO_PIN_6
#define INPUT_08_GPIO_Port GPIOB
#define SWITCH_01_Pin GPIO_PIN_7
#define SWITCH_01_GPIO_Port GPIOB
#define SWITCH_02_Pin GPIO_PIN_10
#define SWITCH_02_GPIO_Port GPIOC
/* USER CODE BEGIN Private defines */

/* USER CODE END Private defines */

#ifdef __cplusplus
}
#endif

#endif /* __MAIN_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
